ui_print " "

# info
MODVER=`grep_prop version $MODPATH/module.prop`
MODVERCODE=`grep_prop versionCode $MODPATH/module.prop`
ui_print " ID=$MODID"
ui_print " Version=$MODVER"
ui_print " VersionCode=$MODVERCODE"
ui_print " MagiskVersion=$MAGISK_VER"
ui_print " MagiskVersionCode=$MAGISK_VER_CODE"
ui_print " "

# architecture
if [ "$ARCH" == arm64 ] || [ "$ARCH" == arm ]; then
  if getprop | grep -Eq "waves.32\]: \[1"; then
    ARCH=arm
  fi
  ui_print "- Architecture $ARCH"
  ui_print " "
else
  ui_print "! Unsupported architecture $ARCH. This module is only for"
  ui_print "  arm64 or arm architecture."
  abort
fi

# bit
if [ "$IS64BIT" != true ]; then
  ui_print "- 32 bit"
  rm -rf `find $MODPATH/system -type d -name *64`
else
  ui_print "- 64 bit"
fi
ui_print " "

# sdk
NUM=26
if [ "$API" -lt $NUM ]; then
  ui_print "! Unsupported SDK $API. You have to upgrade your"
  ui_print "  Android version at least SDK API $NUM to use this"
  ui_print "  module."
  abort
else
  ui_print "- SDK $API"
  if [ "$API" -lt 30 ] || getprop | grep -Eq "waves.10\]: \[1"; then
    ui_print "  Using legacy version"
    cp -rf $MODPATH/system10/* $MODPATH/system
  fi
  ui_print " "
fi

# .aml.sh
mv -f $MODPATH/aml.sh $MODPATH/.aml.sh

# magisk
if [ -d /sbin/.magisk ]; then
  MAGISKTMP=/sbin/.magisk
else
  MAGISKTMP=`find /dev -mindepth 2 -maxdepth 2 -type d -name .magisk`
fi

# function
NAME=_ZN7android23sp_report_stack_pointerEv
if [ "$BOOTMODE" == true ]; then
  LIB=$MAGISKTMP/mirror/system/lib*/libaudioclient.so
else
  LIB=/system/lib*/libaudioclient.so
fi
if [ "$API" -gt 29 ]; then
  ui_print "- Checking $NAME function..."
  ui_print "  Please wait..."
  if ! grep -Eq $NAME $LIB; then
    ui_print "  Using legacy apps"
    cp -rf $MODPATH/system10/* $MODPATH/system
  fi
  ui_print " "
fi
rm -rf $MODPATH/system10

# edge
if getprop | grep -Eq "waves.edge\]: \[1"; then
  ui_print "- Using Moto Waves Edge (racer) config"
  cp -rf $MODPATH/systemedge/* $MODPATH/system
  ui_print " "
fi
rm -rf $MODPATH/systemedge

# mod ui
if getprop | grep -Eq "waves.mod.ui\]: \[1"; then
  APP=MotoWaves
  FILE=/sdcard/$APP.apk
  DES=$MODPATH/system/priv-app/$APP
  ui_print "- Using modified UI apk..."
  if [ -f $FILE ]; then
    cp -f $FILE $DES
    chmod 0644 $DES/$APP.apk
    ui_print "  Modded UI apk is applied"
  else
    ui_print "  ! There is no $FILE file."
    ui_print "    Please place the apk to your internal storage first"
    ui_print "    and reflash!"
  fi
  ui_print " "
fi

# cleaning
ui_print "- Cleaning..."
APP="MotoWaves
     WavesService
     MotoSignatureApp
     com.motorola.motowaves
     com.waves.maxxservice
     com.motorola.motosignature.app"
for APPS in $APP; do
  rm -f `find /data/dalvik-cache /data/system/package_cache -type f -name *$APPS*`
done
rm -rf /metadata/magisk/$MODID
rm -rf /mnt/vendor/persist/magisk/$MODID
rm -rf /persist/magisk/$MODID
rm -rf /data/unencrypted/magisk/$MODID
rm -rf /cache/magisk/$MODID
rm -f $MODPATH/LICENSE
ui_print " "

# store
cleanup() {
  sh $FOLDER/uninstall.sh
  FOLDER=/data/adb/modules_update/$MODID
  sh $FOLDER/uninstall.sh
}

# cleanup
FOLDER=/data/adb/modules/$MODID
FILE=$FOLDER/module.prop
if getprop | grep -Eq "waves.cleanup\]: \[1"; then
  ui_print "- Cleaning-up $MODID data..."
  cleanup
  ui_print " "
elif [ -d $FOLDER ] && ! grep -Eq "$MODNAME" $FILE; then
  ui_print "- Different version detected"
  ui_print "  Cleaning-up $MODID data..."
  cleanup
  ui_print " "
fi

# store
extract() {
  rm -rf $TMPDIR/*
  unzip -d $TMPDIR -o $FILE $DES
  cp -f $TMPDIR/$DES $FOLDER
}

# extract
APP=MotoWaves
ui_print "- Extracting $APP.apk libs..."
if getprop | grep -Eq "waves.32\]: \[1"; then
  PROP=armeabi-v7a
else
  PROP=`getprop ro.product.cpu.abi`
fi
FILE=$MODPATH/system/priv-app/$APP/$APP.apk
DES=lib/$PROP/*
FOLDER=$MODPATH/system/priv-app/$APP/lib/$ARCH
mkdir $FOLDER
chmod 0755 $FOLDER
extract
ui_print " "

# extract
APP=WavesService
ui_print "- Extracting $APP.apk libs..."
FILE=$MODPATH/system/priv-app/$APP/$APP.apk
DES=lib/armeabi-v7a/*
FOLDER=$MODPATH/system/priv-app/$APP/lib/arm
extract
ui_print " "

# store
hide_app() {
  mkdir $MODPATH/system/app/$APP
  touch $MODPATH/system/app/$APP/.replace
  mkdir $MODPATH/system/priv-app/$APP
  touch $MODPATH/system/priv-app/$APP/.replace
  mkdir $MODPATH/system/product/app/$APP
  touch $MODPATH/system/product/app/$APP/.replace
  mkdir $MODPATH/system/product/priv-app/$APP
  touch $MODPATH/system/product/priv-app/$APP/.replace
  mkdir $MODPATH/system/product/preinstall/$APP
  touch $MODPATH/system/product/preinstall/$APP/.replace
}
check_app() {
  FILE=`find /system /product -type f -name $APP.apk`
  if echo $FILE | grep -Eq apk; then
    ui_print "  Checking $APP app..."
    ui_print "  Please wait..."
    if grep -Eq $UUID $FILE; then
      ui_print "  Your $APP app will be hidden"
      hide_app
    fi
  fi
}

# hide
APP=MotoWavesV2
hide_app
APP=WavesServiceV2
hide_app

# dirac
if getprop | grep -Eq "waves.disable.dirac\]: \[1"; then
  ui_print "- Activating dirac disabler..."
  sed -i 's/#1//g' $MODPATH/.aml.sh
  UUID=e069d9e0-8329-11df-9168-0002a5d5c51b
  APP=XiaomiParts
  check_app
  APP=ZenfoneParts
  check_app
  APP=ZenParts
  check_app
  APP=GalaxyParts
  check_app
  ui_print " "
fi

# misoundfx
if getprop | grep -Eq "waves.disable.misoundfx\]: \[1"; then
  ui_print "- Activating misoundfx disabler..."
  sed -i 's/#2//g' $MODPATH/.aml.sh
  UUID=5b8e36a5-144a-4c38-b1d7-0002a5d5c51b
  APP=XiaomiParts
  check_app
  APP=ZenfoneParts
  check_app
  APP=ZenParts
  check_app
  APP=GalaxyParts
  check_app
  ui_print " "
fi

# stream mode
PROP=`getprop stream.mode`
FILE=$MODPATH/.aml.sh
if echo "$PROP" | grep -Eq m; then
  ui_print "- Activating music stream..."
  sed -i 's/#m//g' $FILE
  sed -i 's/musicstream=/musicstream=true/g' $MODPATH/acdb.conf
  ui_print " "
else
  APP=AudioFX
  hide_app
  APP=MusicFX
  hide_app
fi
if echo "$PROP" | grep -Eq r; then
  ui_print "- Activating ring stream..."
  sed -i 's/#r//g' $FILE
  ui_print " "
fi
if echo "$PROP" | grep -Eq a; then
  ui_print "- Activating alarm stream..."
  sed -i 's/#a//g' $FILE
  ui_print " "
fi
if echo "$PROP" | grep -Eq v; then
  ui_print "- Activating voice_call stream..."
  sed -i 's/#v//g' $FILE
  ui_print " "
fi
if echo "$PROP" | grep -Eq n; then
  ui_print "- Activating notification stream..."
  sed -i 's/#n//g' $FILE
  ui_print " "
fi

# permission
ui_print "- Setting permission..."
FOLDER=`find $MODPATH/system/vendor -type d`
for FOLDERS in $FOLDER; do
  chown 0.2000 $FOLDERS
done
chcon -R u:object_r:system_lib_file:s0 $MODPATH/system/lib*
chcon -R u:object_r:vendor_file:s0 $MODPATH/system/vendor
chcon -R u:object_r:vendor_configs_file:s0 $MODPATH/system/vendor/etc
chcon -R u:object_r:vendor_configs_file:s0 $MODPATH/system/vendor/odm/etc
ui_print " "


#files_replace
REPLACE="
/system/app/MiSound/MiSound.apk
/system/vendor/etc/dolby/dax-default.xml
"


